# -*- coding: utf-8 -*-

"""Top-level package for odut."""

__author__ = """Ming Lyu"""
__email__ = 'minglyupolimi@gmail.com'
__version__ = '1.1.2'

import sys
from pathlib import Path
sys.path.append(Path(__file__).parent)